"""osinaweb URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/4.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""

from django.urls import path, include
from osinacore import views
from django.conf.urls.static import static
from django.conf import settings

urlpatterns = [
    path('add/', include('osinacore.add.urls')),
    path('edit/', include('osinacore.edit.urls')),
    path('delete/', include('osinacore.delete.urls')),

    
    path('login', views.signin, name='signin'),
    path('go_online/', views.go_online, name='go_online'),
    path('logout/', views.signout, name='signout'),
    path('', views.home, name='home'),
    path('statusmobilemodal/', views.status_mobile_modal, name='statusmobilemodal'),
    path('userrecentativities/<int:user_id>', views.user_recent_activities_modal, name='userrecentativities'),

    #Listing Templates
    path('customers/', views.customers, name='customers'),
    path('businesses/', views.businesses, name='businesses'),
    path('staffs/', views.staffs, name='users'),
    path('my-projects/', views.my_projects, name='my-projects'),
    path('my-tasks/', views.my_tasks, name='my-tasks'),
    path('my-notes/', views.my_notes, name='my-notes'),
    path('dailyreports/', views.daily_reports, name='dailyreports'),
    path('projecttypes/', views.project_types, name='projecttypes'),
    path('staffpositions/', views.staff_positions, name='staffpositions'),
    path('businesstypes/', views.business_types, name='businesstypes'),
    path('references/', views.references, name='references'),
    path('tags/', views.tags, name='tags'),

    
    

    #Details Templates 
    path('customers/<str:customer_id>/', views.customerdetails, name='customerdetails'),
    path('businesses/<str:business_id>/', views.businessdetails, name='businessdetails'),
    path('staffs/<str:staff_id>/', views.staffdetails, name='userdetails'),
    path('projectdetails/<str:project_id>/', views.projectdetails, name='detailed-project'),
    path('tasks/<str:task_id>/', views.taskdetails, name='detailed-task'),
    path('show-points/<str:task_id>/', views.show_points_modal, name='showpoints'),
    path('timeline/', views.timeline_modal, name='timeline'),
    

    #Fetch urls
    path('get_tasks/<int:epic_id>/', views.get_tasks, name='get_tasks'),
    path('open_tasks_for_project/<int:project_id>/', views.open_tasks_for_project, name='open_tasks_for_project'),
    path('getupdatedlaststatus/', views.get_updated_last_status, name='getupdatedlaststatus'),
    path('getupdatedactivities/', views.get_latest_activities, name='getupdatedactivities'),
    path('recent-activities-page/', views.recent_activities_page, name='recentactivitiespage'),
    path('fetch_epics/', views.fetch_epics, name='fetch_epics'),


    path('add_reaction/<int:status_id>/<str:emoji>/', views.add_reaction, name='add_reaction'),

    #CUSTOMER DASHBOARD
    path('customerdashboard/', views.customer_index, name='customerdashboard'),
    path('customerinvoices/', views.customer_invoices, name='customerinvoices'),
]

urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)